@@ -10,7 +10,7 @@ from plumbum.colorlib.styles import Style, ANSIStyle, HTMLStyle, ColorNotFound
 ansicolors = StyleFactory(ANSIStyle)
 htmlcolors = StyleFactory(HTMLStyle)
 
-def load_ipython_extension(ipython):
+def load_ipython_extension(ipython): # pragma: no cover
     try:
         from plumbum.colorlib._ipython_ext import OutputMagics
     except ImportError:
@@ -20,7 +20,7 @@ def load_ipython_extension(ipython):
     ipython.push({"colors":htmlcolors})
     ipython.register_magics(OutputMagics)
 
-def main():
+def main(): # pragma: no cover
     """Color changing script entry. Call using
     python -m plumbum.colors, will reset if no arguments given."""
     import sys
