@@ -35,14 +35,16 @@ def get_color_repr():
     term =local.env.get("TERM", "")
 
     # Some terminals set TERM=xterm for compatibility
-    if term == "xterm-256color" or term == "xterm":
+    if term.endswith("256color") or term == "xterm":
         return 3 if platform.system() == 'Darwin' else 4
-    elif term == "xterm-16color":
+    elif term.endswith("16color"):
         return 2
-    elif os.name == 'nt':
+    elif term == "screen":
         return 1
+    elif os.name == 'nt':
+        return 0
     else:
-        return False
+        return 3
 
 class ColorNotFound(Exception):
     """Thrown when a color is not valid for a particular method."""
@@ -104,7 +106,7 @@ class Color(ABC):
 
         """
 
-    __slots__ = ('fg', 'isreset', 'rgb', 'number', 'representation', 'exact')
+    __slots__ = ('fg', 'isreset', 'rgb', 'number', 'representation', 'exact', '__weakref__')
 
     def __init__(self, r_or_color=None, g=None, b=None, fg=True):
         """This works from color values, or tries to load non-simple ones."""
@@ -331,7 +333,7 @@ class Style(object):
     and can be called in a with statement.
     """
 
-    __slots__ = ('attributes','fg', 'bg', 'isreset')
+    __slots__ = ('attributes','fg', 'bg', 'isreset', '__weakref__')
 
     color_class = Color
     """The class of color to use. Never hardcode ``Color`` call when writing a Style
@@ -509,10 +511,12 @@ class Style(object):
     def __enter__(self):
         """Context manager support"""
         self.stdout.write(str(self))
+        self.stdout.flush()
 
     def __exit__(self, type, value, traceback):
         """Runs even if exception occurred, does not catch it."""
         self.stdout.write(str(~self))
+        self.stdout.flush()
         return False
 
     @property
