@@ -16,6 +16,7 @@ from plumbum.lib import ProcInfo, IS_WIN32, six, StaticProperty
 from plumbum.commands.daemons import win32_daemonize, posix_daemonize
 from plumbum.commands.processes import iter_lines
 from plumbum.machines.base import BaseMachine
+from plumbum.machines.base import PopenAddons
 from plumbum.machines.env import BaseEnv
 
 if sys.version_info >= (3, 2):
@@ -31,11 +32,12 @@ else:
         from subprocess import Popen, PIPE
         has_new_subprocess = False
 
-class IterablePopen(Popen):
+class IterablePopen(Popen, PopenAddons):
     iter_lines = iter_lines
     def __iter__(self):
         return self.iter_lines()
 
+
 logger = logging.getLogger("plumbum.local")
 
 
@@ -141,7 +143,7 @@ class LocalMachine(BaseMachine):
             for p in cls.env.path:
                 for ext in cls._EXTENSIONS:
                     fn = p / (progname + ext)
-                    if fn.access("x"):
+                    if fn.access("x") and not fn.is_dir():
                         return fn
             return None
     else:
@@ -149,7 +151,7 @@ class LocalMachine(BaseMachine):
         def _which(cls, progname):
             for p in cls.env.path:
                 fn = p / progname
-                if fn.access("x"):
+                if fn.access("x") and not fn.is_dir():
                     return fn
             return None
 
@@ -293,7 +295,11 @@ class LocalMachine(BaseMachine):
             """
             import csv
             tasklist = local["tasklist"]
-            lines = tasklist("/V", "/FO", "CSV").splitlines()
+            output = tasklist("/V", "/FO", "CSV")
+            if not six.PY3:
+                # The Py2 csv reader does not support non-ascii values
+                output = output.encode('ascii', 'ignore')
+            lines = output.splitlines()
             rows = csv.reader(lines)
             header = next(rows)
             imgidx = header.index('Image Name')
