@@ -36,7 +36,12 @@ class RemotePath(Path):
             raise TypeError("At least one path part is required (none given)")
         windows = (remote.uname.lower() == "windows")
         normed = []
-        parts = (remote._session.run("pwd")[1].strip(),) + parts
+
+        # Simple skip if path is absolute
+        if parts[0][0] not in ("/","\\"):
+            cwd = (remote._cwd if hasattr(remote, '_cwd') else remote._session.run("pwd")[1].strip())
+            parts = (cwd,) + parts
+
         for p in parts:
             if windows:
                 plist = str(p).replace("\\", "/").split("/")
@@ -211,6 +216,12 @@ class RemotePath(Path):
             if isinstance(dst, six.string_types):
                 dst = RemotePath(self.remote, dst)
             dst.remove()
+        else:
+            if isinstance(dst, six.string_types):
+                dst = RemotePath(self.remote, dst)
+            if dst.exists():
+                raise TypeError("Override not specified and dst exists")
+
         self.remote._path_copy(self, dst)
 
     @_setdoc(Path)
@@ -229,6 +240,10 @@ class RemotePath(Path):
             data = data.encode(encoding)
         self.remote._path_write(self, data)
 
+    @_setdoc(Path)
+    def touch(self):
+        self.remote._path_touch(str(self))
+
     @_setdoc(Path)
     def chown(self, owner = None, group = None, recursive = None):
         self.remote._path_chown(self, owner, group, self.is_dir() if recursive is None else recursive)
@@ -298,6 +313,8 @@ class RemoteWorkdir(RemotePath):
     def chdir(self, newdir):
         """Changes the current working directory to the given one"""
         self.remote._session.run("cd %s" % (shquote(newdir),))
+        if hasattr(self.remote, '_cwd'):
+            del self.remote._cwd
         return self.__class__(self.remote)
 
     def getpath(self):
